==> gthumb-2.12.3-i486-72.1.txz: usr/src/gthumb-2.12.3/build-gthumb.sh <==
#!/bin/bash
#
# http://ftp.gnome.org/pub/gnome/sources/gthumb/2.12/gthumb-2.12.3.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='gthumb'
softversion='2.12.3'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static \
  --enable-libopenraw \
  --disable-schemas-install \
  --disable-scrollkeeper \
  --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make
make install DESTDIR=$dest

# gconf stuff
export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
     gconftool-2 --makefile-install-rule $schema
done
# Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  
# Documentation  
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL MAINTAINERS NEWS README \
$dest/usr/doc/$soft-$softversion
  
# Description file
mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

      |-----handy-ruler----------------------------------------------------|
gthumb: Gthumb - is An Image Viewer and Browser for the GNOME Desktop
gthumb:
gthumb: gThumb is an image viewer written for the GNOME environment.It lets
gthumb: you browse your hard disk, showing you thumbnails of image files.
gthumb: It also lets you view single files (including GIF animations),
gthumb: organize images in catalogs, print images, view slideshows, set
gthumb: your desktop background, and more. gThumb also supports Nautilus
gthumb: thumbnails.
gthumb:
gthumb:
gthumb:
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5

==> gthumb-2.14.3-i486-72.1.txz: usr/src/gthumb-2.14.3/build-gthumb.sh <==
#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/gthumb/2.14/gthumb-2.14.3.tar.xz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='gthumb'
softversion='2.14.3'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static \
  --disable-scrollkeeper \
  --enable-libopenraw \
  --disable-libbrasero \
  --disable-schemas-install \
  --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make -j6
make install DESTDIR=$dest

# gconf stuff
export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
     gconftool-2 --makefile-install-rule $schema
done
# Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  
# Documentation  
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL MAINTAINERS NEWS README \
$dest/usr/doc/$soft-$softversion
  
# Description file
mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

      |-----handy-ruler----------------------------------------------------|
gthumb: Gthumb - is An Image Viewer and Browser for the GNOME Desktop
gthumb:
gthumb: gThumb is an image viewer written for the GNOME environment.It lets
gthumb: you browse your hard disk, showing you thumbnails of image files.
gthumb: It also lets you view single files (including GIF animations),
gthumb: organize images in catalogs, print images, view slideshows, set
gthumb: your desktop background, and more. gThumb also supports Nautilus
gthumb: thumbnails.
gthumb:
gthumb:
gthumb:
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
